VW Validator

### Vowpal Wabbit Data Format Validation

by Ben Gimpert

Not sure if your training data is in the right format for Vowpal Wabbit? Not seeing the results you expect from Vowpal Wabbit, in general? Paste a few lines of your training data into this text box, and then hit the “Validate” button below. Note that the only unambiguous prefixes for training examples have exactly one or four elements.

1 1.0 |MetricFeatures:3.28 height:1.5 length:2.0 |Says black with white stripes |OtherFeatures NumberOfLegs:4.0 HasStripes 1 1.0 zebra|MetricFeatures:3.28 height:1.5 length:2.0 |Says black with white stripes |OtherFeatures NumberOfLegs:4.0 HasStripes 1 2 'tag| a:2 b:3 1 2 'tag | a:2 b:3 1 2 tag | a:2 b:3 0 | price:.23 sqft:.25 age:.05 2006 1 2 'second_house | price:.18 sqft:.15 age:.35 1976 0 1 0.5 'third_house | price:.53 sqft:.32 age:.87 1924